==> odata-client-microsoft-dynamics-0.1.38-sources.jar: microsoft/dynamics/crm/entity/collection/request/ProcesssessionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Processsession;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.WorkflowlogRequest;
import microsoft.dynamics.crm.schema.SchemaInfo;

public class ProcesssessionCollectionRequest extends CollectionPageEntityRequest<Processsession, ProcesssessionRequest>{

    protected ContextPath contextPath;

    public ProcesssessionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Processsession.class, cp -> new ProcesssessionRequest(cp, Optional.empty()), SchemaInfo.INSTANCE, value);
        this.contextPath = contextPath;
    }

    public WorkflowlogCollectionRequest lk_workflowlog_processsession() {
        return new WorkflowlogCollectionRequest(contextPath.addSegment("lk_workflowlog_processsession"), Optional.empty());
    }

    public WorkflowlogRequest lk_workflowlog_processsession(String workflowlogid) {
        return new WorkflowlogRequest(contextPath.addSegment("lk_workflowlog_processsession").addKeys(new NameValue(workflowlogid.toString())), Optional.empty());
    }

    public WorkflowlogCollectionRequest lk_workflowlog_processsession_childworkflow() {
        return new WorkflowlogCollectionRequest(contextPath.addSegment("lk_workflowlog_processsession_childworkflow"), Optional.empty());
    }

    public WorkflowlogRequest lk_workflowlog_processsession_childworkflow(String workflowlogid) {
        return new WorkflowlogRequest(contextPath.addSegment("lk_workflowlog_processsession_childworkflow").addKeys(new NameValue(workflowlogid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_previouslinkedsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_previouslinkedsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_previouslinkedsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_previouslinkedsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_nextlinkedsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_nextlinkedsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_nextlinkedsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_nextlinkedsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_originatingsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_originatingsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_originatingsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_originatingsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest processSession_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ProcessSession_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest processSession_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ProcessSession_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest processsession_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("processsession_connections1"), Optional.empty());
    }

    public ConnectionRequest processsession_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("processsession_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest processsession_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("processsession_PostFollows"), Optional.empty());
    }

    public PostfollowRequest processsession_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("processsession_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest processsession_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("processsession_connections2"), Optional.empty());
    }

    public ConnectionRequest processsession_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("processsession_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PostregardingCollectionRequest processsession_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("processsession_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest processsession_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("processsession_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

}

==> odata-client-microsoft-dynamics-0.1.39-sources.jar: microsoft/dynamics/crm/entity/collection/request/ProcesssessionCollectionRequest.java <==
package microsoft.dynamics.crm.entity.collection.request;

import com.github.davidmoten.odata.client.CollectionPageEntityRequest;
import com.github.davidmoten.odata.client.ContextPath;
import com.github.davidmoten.odata.client.NameValue;
import com.github.davidmoten.odata.client.internal.RequestHelper;

import java.lang.Object;
import java.lang.String;
import java.util.Optional;

import microsoft.dynamics.crm.entity.Processsession;
import microsoft.dynamics.crm.entity.request.ConnectionRequest;
import microsoft.dynamics.crm.entity.request.PostfollowRequest;
import microsoft.dynamics.crm.entity.request.PostregardingRequest;
import microsoft.dynamics.crm.entity.request.ProcesssessionRequest;
import microsoft.dynamics.crm.entity.request.SyncerrorRequest;
import microsoft.dynamics.crm.entity.request.WorkflowlogRequest;

public class ProcesssessionCollectionRequest extends CollectionPageEntityRequest<Processsession, ProcesssessionRequest>{

    protected ContextPath contextPath;

    public ProcesssessionCollectionRequest(ContextPath contextPath, Optional<Object> value) {
        super(contextPath, Processsession.class, cp -> new ProcesssessionRequest(cp, Optional.empty()), value);
        this.contextPath = contextPath;
    }

    public WorkflowlogCollectionRequest lk_workflowlog_processsession() {
        return new WorkflowlogCollectionRequest(contextPath.addSegment("lk_workflowlog_processsession"), Optional.empty());
    }

    public WorkflowlogRequest lk_workflowlog_processsession(String workflowlogid) {
        return new WorkflowlogRequest(contextPath.addSegment("lk_workflowlog_processsession").addKeys(new NameValue(workflowlogid.toString())), Optional.empty());
    }

    public WorkflowlogCollectionRequest lk_workflowlog_processsession_childworkflow() {
        return new WorkflowlogCollectionRequest(contextPath.addSegment("lk_workflowlog_processsession_childworkflow"), Optional.empty());
    }

    public WorkflowlogRequest lk_workflowlog_processsession_childworkflow(String workflowlogid) {
        return new WorkflowlogRequest(contextPath.addSegment("lk_workflowlog_processsession_childworkflow").addKeys(new NameValue(workflowlogid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_previouslinkedsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_previouslinkedsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_previouslinkedsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_previouslinkedsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_nextlinkedsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_nextlinkedsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_nextlinkedsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_nextlinkedsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public ProcesssessionCollectionRequest lk_processsession_originatingsessionid() {
        return new ProcesssessionCollectionRequest(contextPath.addSegment("lk_processsession_originatingsessionid"), Optional.empty());
    }

    public ProcesssessionRequest lk_processsession_originatingsessionid(String processsessionid) {
        return new ProcesssessionRequest(contextPath.addSegment("lk_processsession_originatingsessionid").addKeys(new NameValue(processsessionid.toString())), Optional.empty());
    }

    public SyncerrorCollectionRequest processSession_SyncErrors() {
        return new SyncerrorCollectionRequest(contextPath.addSegment("ProcessSession_SyncErrors"), Optional.empty());
    }

    public SyncerrorRequest processSession_SyncErrors(String syncerrorid) {
        return new SyncerrorRequest(contextPath.addSegment("ProcessSession_SyncErrors").addKeys(new NameValue(syncerrorid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest processsession_connections1() {
        return new ConnectionCollectionRequest(contextPath.addSegment("processsession_connections1"), Optional.empty());
    }

    public ConnectionRequest processsession_connections1(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("processsession_connections1").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PostfollowCollectionRequest processsession_PostFollows() {
        return new PostfollowCollectionRequest(contextPath.addSegment("processsession_PostFollows"), Optional.empty());
    }

    public PostfollowRequest processsession_PostFollows(String postfollowid) {
        return new PostfollowRequest(contextPath.addSegment("processsession_PostFollows").addKeys(new NameValue(postfollowid.toString())), Optional.empty());
    }

    public ConnectionCollectionRequest processsession_connections2() {
        return new ConnectionCollectionRequest(contextPath.addSegment("processsession_connections2"), Optional.empty());
    }

    public ConnectionRequest processsession_connections2(String connectionid) {
        return new ConnectionRequest(contextPath.addSegment("processsession_connections2").addKeys(new NameValue(connectionid.toString())), Optional.empty());
    }

    public PostregardingCollectionRequest processsession_PostRegardings() {
        return new PostregardingCollectionRequest(contextPath.addSegment("processsession_PostRegardings"), Optional.empty());
    }

    public PostregardingRequest processsession_PostRegardings(String postregardingid) {
        return new PostregardingRequest(contextPath.addSegment("processsession_PostRegardings").addKeys(new NameValue(postregardingid.toString())), Optional.empty());
    }

}
